A Series of unfortunate blogs
#############################

:date: 2010-05-09 08:46
:category: Alt
:featured: True

I woke up this morning to discover that I had turned into a rather
large root vegetable, possibly a turnip or parsnip, it was hard to tell.

What happened next
------------------

Reader, they pureed me!


